=====================
Deltares Wave Toolbox
=====================






A Python toolbox for wave analysis



Features
--------

From a time series of water level elevations, the toolbox can calculate:

* the wave spectrum
* spectral wave parameters such as wave heigth and different wave periods
* wave height exceedance curves
* theoretical wave spectra and wave height distributions
* linear decomposition into incoming and reflected waves (using multiple wave gauges)

How to install the toolbox?
-----------------------------

The package is available at pip. To install the package run:

`pip install deltares-wave-toolbox`

Where to find information about the Deltares Wave Toolbox?
----------------------------------------------------------

See the online manual for information about the toolbox. In addition, the examples folder contains scripts with applications of the toolbox and a Jupyter notebook is available in the documentation folder.


Credits
-------

* Jan Kramer <jan.kramer@deltares.nl>
* Menno de Ridder <menno.deridder@deltares.nl>
* Ivo van der Werf <ivo.vanderwerf@deltares.nl>
* Joost den Bieman <joost.denbieman@deltares.nl>
